@@ -5,6 +5,7 @@ from typing import Optional, Tuple
 import torch
 from torch import Tensor
 
+from .. import settings
 from ..utils.broadcasting import _mul_broadcast_shape
 from ..utils.memoize import cached
 from .lazy_tensor import LazyTensor
@@ -63,10 +64,7 @@ class DiagLazyTensor(TriangularLazyTensor):
         return self.__class__(self._diag * constant.unsqueeze(-1))
 
     def _mul_matrix(self, other):
-        if isinstance(other, DiagLazyTensor):
-            return self.__class__(self._diag * other._diag)
-        else:
-            return self.__class__(self._diag * other.diag())
+        return DiagLazyTensor(self.diag() * other.diag())
 
     def _prod_batch(self, dim):
         return self.__class__(self._diag.prod(dim))
@@ -85,7 +83,7 @@ class DiagLazyTensor(TriangularLazyTensor):
         return self.sqrt()
 
     def _root_inv_decomposition(self, initial_vectors=None):
-        return DiagLazyTensor(self._diag.reciprocal()).sqrt()
+        return self.inverse().sqrt()
 
     def _size(self):
         return self._diag.shape + self._diag.shape[-1:]
@@ -101,7 +99,7 @@ class DiagLazyTensor(TriangularLazyTensor):
         return self
 
     def abs(self):
-        return DiagLazyTensor(self._diag.abs())
+        return self.__class__(self._diag.abs())
 
     def add_diag(self, added_diag):
         shape = _mul_broadcast_shape(self._diag.shape, added_diag.shape)
@@ -117,10 +115,10 @@ class DiagLazyTensor(TriangularLazyTensor):
         return torch.diag_embed(self._diag)
 
     def exp(self):
-        return DiagLazyTensor(self._diag.exp())
+        return self.__class__(self._diag.exp())
 
     def inverse(self):
-        return DiagLazyTensor(self._diag.reciprocal())
+        return self.__class__(self._diag.reciprocal())
 
     def inv_matmul(self, right_tensor, left_tensor=None):
         res = self.inverse()._matmul(right_tensor)
@@ -153,7 +151,7 @@ class DiagLazyTensor(TriangularLazyTensor):
         return inv_quad_term, logdet_term
 
     def log(self):
-        return DiagLazyTensor(self._diag.log())
+        return self.__class__(self._diag.log())
 
     def matmul(self, other):
         from .triangular_lazy_tensor import TriangularLazyTensor
@@ -170,16 +168,15 @@ class DiagLazyTensor(TriangularLazyTensor):
         return super().matmul(other)
 
     def sqrt(self):
-        return DiagLazyTensor(self._diag.sqrt())
+        return self.__class__(self._diag.sqrt())
 
     def sqrt_inv_matmul(self, rhs, lhs=None):
+        matrix_inv_root = self._root_inv_decomposition()
         if lhs is None:
-            return DiagLazyTensor(1.0 / (self._diag.sqrt())).matmul(rhs)
+            return matrix_inv_root.matmul(rhs)
         else:
-            matrix_inv_root = DiagLazyTensor(1.0 / (self._diag.sqrt()))
-            sqrt_inv_matmul = lhs @ DiagLazyTensor(1.0 / (self._diag.sqrt())).matmul(rhs)
+            sqrt_inv_matmul = lhs @ matrix_inv_root.matmul(rhs)
             inv_quad = (matrix_inv_root @ lhs.transpose(-2, -1)).transpose(-2, -1).pow(2).sum(dim=-1)
-
             return sqrt_inv_matmul, inv_quad
 
     def zero_mean_mvn_samples(self, num_samples):
@@ -197,7 +194,8 @@ class DiagLazyTensor(TriangularLazyTensor):
     def _symeig(self, eigenvectors: bool = False) -> Tuple[Tensor, Optional[LazyTensor]]:
         evals = self._diag
         if eigenvectors:
-            evecs = DiagLazyTensor(torch.ones_like(evals))
+            diag_values = torch.ones(evals.shape[:-1], device=evals.device, dtype=evals.dtype).unsqueeze(-1)
+            evecs = ConstantDiagLazyTensor(diag_values, diag_shape=evals.shape[-1])
         else:
             evecs = None
         return evals, evecs
@@ -210,18 +208,83 @@ class ConstantDiagLazyTensor(DiagLazyTensor):
         Used e.g. for adding jitter to matrices.
 
         Args:
-            :attr:`n` (int):
-                The (non-batch) dimension of the (square) matrix
             :attr:`diag_values` (Tensor):
                 A `b1 x ... x bk x 1` Tensor, representing a `b1 x ... x bk`-sized batch
-                of `n x n` diagonal matrices
+                of `diag_shape x diag_shape` diagonal matrices
+            :attr:`diag_shape` (int):
+                The (non-batch) dimension of the (square) matrix
         """
+        if settings.debug.on():
+            if not (diag_values.dim() and diag_values.size(-1) == 1):
+                raise ValueError(
+                    f"diag_values argument to ConstantDiagLazyTensor needs to have a final "
+                    f"singleton dimension. Instead, got a value with shape {diag_values.shape}."
+                )
         super(TriangularLazyTensor, self).__init__(diag_values, diag_shape=diag_shape)
+        self.diag_values = diag_values
         self.diag_shape = diag_shape
-        self._diag = diag_values.expand(*diag_values.shape[:-1], diag_shape)
+
+    def __add__(self, other):
+        if isinstance(other, ConstantDiagLazyTensor):
+            if other.shape[-1] == self.shape[-1]:
+                return ConstantDiagLazyTensor(self.diag_values + other.diag_values, self.diag_shape)
+            raise RuntimeError(
+                f"Trailing batch shapes must match for adding two ConstantDiagLazyTensors. "
+                f"Instead, got shapes of {other.shape} and {self.shape}."
+            )
+        return super().__add__(other)
+
+    @property
+    def _diag(self):
+        return self.diag_values.expand(*self.diag_values.shape[:-1], self.diag_shape)
 
     def _expand_batch(self, batch_shape):
-        return self.__class__(self._diag.expand(*batch_shape, self._diag.size(-1)), diag_shape=self.diag_shape)
+        return self.__class__(self.diag_values.expand(*batch_shape, 1), diag_shape=self.diag_shape)
+
+    def _mul_constant(self, constant):
+        return self.__class__(self.diag_values * constant, diag_shape=self.diag_shape)
+
+    def _mul_matrix(self, other):
+        if isinstance(other, ConstantDiagLazyTensor):
+            if not self.diag_shape == other.diag_shape:
+                raise ValueError(
+                    "Dimension Mismatch: Must have same diag_shape, but got "
+                    f"{self.diag_shape} and {other.diag_shape}"
+                )
+            return self.__class__(self.diag_values * other.diag_values, diag_shape=self.diag_shape)
+        return super()._mul_matrix(other)
+
+    def _prod_batch(self, dim):
+        return self.__class__(self.diag_values.prod(dim), diag_shape=self.diag_shape)
+
+    def _quad_form_derivative(self, left_vecs, right_vecs):
+        # TODO: Use proper batching for input vectors (prepand to shape rathern than append)
+        if not self.diag_values.requires_grad:
+            return (None,)
+
+        res = (left_vecs * right_vecs).sum(dim=[-1, -2])
+        res = res.unsqueeze(-1)
+        return (res,)
 
     def _sum_batch(self, dim):
-        return self.__class__(self._diag.sum(dim), diag_shape=self.diag_shape)
+        return self.__class__(self.diag_values.sum(dim), diag_shape=self.diag_shape)
+
+    def abs(self):
+        return self.__class__(self.diag_values.abs(), diag_shape=self.diag_shape)
+
+    def exp(self):
+        return self.__class__(self.diag_values.exp(), diag_shape=self.diag_shape)
+
+    def inverse(self):
+        return self.__class__(self.diag_values.reciprocal(), diag_shape=self.diag_shape)
+
+    def log(self):
+        return self.__class__(self.diag_values.log(), diag_shape=self.diag_shape)
+
+    def matmul(self, other):
+        if isinstance(other, ConstantDiagLazyTensor):
+            return self._mul_matrix(other)
+        return super().matmul(other)
+
+    def sqrt(self):
+        return self.__class__(self.diag_values.sqrt(), diag_shape=self.diag_shape)
